TurnThinking class

One reasoning delta from the model provider's thinking() stream.

Inheritance

Constructors

TurnThinking(int turn, ThinkingDelta delta)
const

Properties

delta ThinkingDelta
The provider-emitted reasoning fragment.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turn int
Zero-based turn index this event belongs to.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited