TurnTimeoutError class

Thrown by the per-turn budget when a single turn exceeds the wall- clock budget (PRD 10, default 30s).

Implemented types
Annotations
  • @immutable

Constructors

TurnTimeoutError(int turnIndex)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turnIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited