TurnValidation class

Validation outcome for the turn's chosen action.

Inheritance

Constructors

TurnValidation(int turn, bool ok, String? rejectReason)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ok bool
Whether the validator accepted the action.
final
rejectReason String?
Rejection reason when ok is false; null otherwise.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turn int
Zero-based turn index this event belongs to.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited