CoreFragment class
Core fragment: route stack + semantics nodes (id-keyed) + recent errors.
- Annotations
-
- @immutable
Constructors
-
CoreFragment({required List<
String> routeStack, required Map<int, SemanticsNode> nodes, required List<RuntimeError> errors}) -
const
Properties
-
errors
→ List<
RuntimeError> -
Runtime errors observed since the last cursor.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
nodes
→ Map<
int, SemanticsNode> -
Captured semantics nodes keyed by stable id.
final
-
routeStack
→ List<
String> -
Best-effort Navigator 1.0 route stack (top route name first/only entry
— see
bestEffortRouteStackon the binding side).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- empty → const CoreFragment